
#if defined(USE_REFLECTION) || defined(USE_LIGHT)
	#ifndef USE_ALPHA
		#define USE_ALPHA
	#endif 
#endif 
uniform lowp sampler2D 	MainTextureSampler;
uniform lowp sampler2D 	CloudNoiseTexture;
#ifdef STONE_TEXTURE
	uniform lowp sampler2D 	StoneTextureSampler;
	uniform lowp sampler2D 	StoneTextureSampler_alpha;
	uniform lowp    int		StoneTextureSampler_alphachannel;
#endif
#ifdef STONE_MIX
uniform lowp float 	StoneFactor;
#endif
#ifdef SPLIT_ALPHA
uniform lowp    sampler2D MainTextureSampler_alpha;
uniform lowp    int       MainTextureSampler_alphachannel;
#endif 
varying		mediump	vec2 	vCoord0;
#ifdef USE_VCOLOR
	varying		lowp	vec3	vColor;
#endif 
#ifdef STONE_MIX
	varying		mediump	vec2 	vCoord1;
#endif
#if defined(USE_REFLECTION) || defined(USE_LIGHT)
	
	varying mediump vec3 vertex_world_normal;
	varying highp 	vec3 vertex_world_pos;
	uniform highp vec3 camera_pos;
	uniform lowp sampler2D SphericalMap_Diffuse_Refl;
	#ifdef SPLIT_ALPHA
		uniform lowp sampler2D 		SphericalMap_Diffuse_Refl_alpha;
		uniform lowp    int       	SphericalMap_Diffuse_Refl_alphachannel;
	#endif 
#endif 
lowp vec4 GetMainColor(lowp vec2 textCoord)
{
#ifdef USE_ALPHA
	#ifdef SPLIT_ALPHA
		return vec4(texture2D(MainTextureSampler, textCoord, -1.0).rgb, texture2D(MainTextureSampler_alpha, textCoord,-1.0)[MainTextureSampler_alphachannel]);
	#else
		return texture2D(MainTextureSampler, textCoord, -1.0);
	#endif
#else
	return vec4(texture2D(MainTextureSampler, textCoord, -1.0).rgb,1.0);
#endif
}
#ifdef STONE_TEXTURE
lowp vec4 GetStoneTexture(lowp vec2 textCoord)
{
	#if defined(SPLIT_ALPHA) && !defined(STONE_MIX)	
		return vec4(texture2D(StoneTextureSampler, textCoord, -1.0).rgb, texture2D(StoneTextureSampler_alpha, textCoord,-1.0)[StoneTextureSampler_alphachannel]);
	#else
		return texture2D(StoneTextureSampler, textCoord, -1.0);
	#endif
}
#endif
void main()
{
	lowp vec4 MainTextureColor = GetMainColor(vCoord0);
		
#if defined(USE_REFLECTION) || defined(USE_LIGHT)
	
	#ifdef USE_VCOLOR
		gl_FragColor = MainTextureColor * vec4(vColor,1.0);		
	#else
		gl_FragColor = MainTextureColor;
	#endif
#if defined(LOW_GPU) || defined(POWERVR_GPU)
	gl_FragColor.a = 0.85; 
#else
	lowp vec3 E = normalize(camera_pos - vertex_world_pos);
	lowp vec3 N = normalize(vertex_world_normal); 
	lowp vec3 texCol = gl_FragColor.xyz;
#ifdef USE_LIGHT
	
	lowp float specMask = 0.0;
	lowp float base_alpha = MainTextureColor.a;
#else
	lowp float specMask = MainTextureColor.a;		
#endif
	
	lowp vec3 shadeBase;
	mediump vec3 dfColor;
	
	{
		
		mediump vec3 sD = N + vec3(0.0, 0.0, 1.0);		
		
		lowp float  kD = 0.5 / sqrt(dot(sD, sD));		
		
		lowp vec2 SphereUV_diffuse = sD.xy * kD + 0.5;	
		
		dfColor = texture2D(SphericalMap_Diffuse_Refl, SphereUV_diffuse).rgb * 2.52;
		dfColor = min(dfColor, 1.0);
		shadeBase = texCol * dfColor;
	}
	
	
	lowp vec3 LR = reflect(-normalize(vec3(0.5,-1.0,1.0)), N); 
	
	lowp float specular = clamp(pow(dot(LR, E), 2.5),0.2,1.0);
	
		specular = specular * 0.7;
	
	
    lowp vec3 sR = reflect(-E, N) + vec3(0.0, 0.0, 1.0);
    
    lowp float  kF = 0.5 / sqrt(dot(sR, sR));
    	
    lowp vec2 SphereUV_refl = sR.xy * kF + 0.5;
    
#ifdef SPLIT_ALPHA
	lowp vec3 reflection = vec3(texture2D(SphericalMap_Diffuse_Refl_alpha, SphereUV_refl)[SphericalMap_Diffuse_Refl_alphachannel]) * (specMask * 1.45);
#else        	
	lowp vec3 reflection = texture2D(SphericalMap_Diffuse_Refl, SphereUV_refl).aaa * (specMask * 1.45);
#endif
		
	
	{
		
		specular = mix(specular, 0.0, min(reflection.r,1.0));
		
		gl_FragColor = vec4(shadeBase + specular*texCol.rgb + reflection, 1.0);				
	}
	
	
	
	
	
	
	
	lowp float f = 1.0 - max(dot(N, E), 0.0);
	f = smoothstep(1.0 - 0.25, 1.0, f);
	f = f * 0.4;
		
	
	lowp vec3 fresnel = vec3(1.0,1.0,1.0) * f;
	#ifdef USE_LIGHT
		gl_FragColor = vec4(gl_FragColor.rgb*(1.0-f) + fresnel,base_alpha); 
	#else
		gl_FragColor = vec4(gl_FragColor.rgb*(1.0-f) + fresnel,1.0); 
	#endif
#endif
#elif defined(USE_VCOLOR) 
	lowp vec4 ret = MainTextureColor * vec4(vColor,1.0);
	gl_FragColor = ret;
#else 
	
	lowp vec4 ret = MainTextureColor;
	gl_FragColor = ret;
#endif 
#ifdef STONE_MIX
	lowp vec3 StoneMap = GetStoneTexture(vCoord1).rgb;
	
	
	
	
	lowp float scale = texture2D(CloudNoiseTexture,vCoord1).r;
	
	lowp float border = (scale - StoneFactor);
	
	lowp float selector = clamp(pow(1.0 - border,64.0),0.0,1.0);
	border = clamp(pow(1.0 - abs(border),64.0),0.0,1.0);
	
	#if defined(LOW_GPU) || defined(POWERVR_GPU) || defined(NVIDIA_TEGRA)
	if(selector > 0.9)
	{
		lowp vec3 blabla = StoneMap * (selector + border);
		gl_FragColor.rgb = gl_FragColor.rgb * (1.0 - selector) + blabla;
	}
	#else
		gl_FragColor = mix(gl_FragColor,vec4(StoneMap,gl_FragColor.a),selector) + vec4(StoneMap * border,0.0);
	#endif
	
#elif defined(STONE_TEXTURE)
	lowp vec4 StoneMap = GetStoneTexture(vCoord0).rgba;
	gl_FragColor = StoneMap;
#endif
}