
#ifdef LOW_GPU
	#ifdef USE_GROUND_CLOUDS
		#undef USE_GROUND_CLOUDS
	#endif
#endif
#ifdef USE_COLORCORECTION	
	uniform lowp mat4 ColorMatrix;	
#endif
uniform lowp sampler2D sampler0;
#ifdef SPLIT_ALPHA
uniform lowp    sampler2D sampler0_alpha;
uniform lowp    int       sampler0_alphachannel;
#endif
varying mediump vec2 vTexCoord0;
varying mediump vec2 vTexCoord1;
varying mediump vec2 vTexCoord2;
varying mediump vec2 vTexCoord3;
varying lowp vec4 vColor0;

#ifndef CLOUDS_VERTEX_FS
#define CLOUDS_VERTEX_FS
#ifdef USE_GROUND_CLOUDS
uniform lowp sampler2D CloudTexture;
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return texture2D(CloudTexture,tex_uv).xyz * 2.00787;
}
#ifndef NO_CLOUD_UV
	varying mediump vec2 cloud_uv_tex_coord;
	mediump vec2 GetCloudUV()
	{
		return cloud_uv_tex_coord;
	}
	lowp vec3 GetCloudColor()
	{
		return GetCloudColor(GetCloudUV());
	}
#endif
#else 
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return vec3(1.0);
}
lowp vec3 GetCloudColor()
{
	return vec3(1.0);
}
#endif 
#endif 

#ifdef USE_UNIT_SHADOW
	uniform lowp sampler2D GroundShadowTexture;
	varying mediump vec2 ground_uv_texture;
#endif
void main()
{
	#ifdef SPLIT_ALPHA			
		
		lowp vec4 c0 = vec4(texture2D(sampler0, vTexCoord0).rgb, texture2D(sampler0_alpha, vTexCoord0).r);
		lowp vec4 c1 = vec4(texture2D(sampler0, vTexCoord1).rgb, texture2D(sampler0_alpha, vTexCoord1).r);
		lowp vec4 c2 = vec4(texture2D(sampler0, vTexCoord2).rgb, texture2D(sampler0_alpha, vTexCoord2).r);
		lowp vec4 c3 = vec4(texture2D(sampler0, vTexCoord3).rgb, texture2D(sampler0_alpha, vTexCoord3).r);
		
	#else		
		lowp vec4 c0 = texture2D(sampler0, vTexCoord0,-1.0);
		lowp vec4 c1 = texture2D(sampler0, vTexCoord1,-1.0);
		lowp vec4 c2 = texture2D(sampler0, vTexCoord2,-1.0);
		lowp vec4 c3 = texture2D(sampler0, vTexCoord3,-1.0);
	#endif
	
	
	
	
#ifdef USE_GROUND_CLOUDS
	lowp vec3 factor = GetCloudColor();
#else
	lowp vec3 factor = vec3(1.0);
#endif
#ifdef USE_UNIT_SHADOW
	lowp float shadow_mask = texture2D(GroundShadowTexture, ground_uv_texture).r;
	lowp vec3 shadow_color = vec3(0.74) * factor;
	factor = mix(factor,shadow_color,shadow_mask);
#endif
	
	
	
	
	
	
	
		
	
	lowp vec3 lerpy012 = c0.rgb  + (c2.rgb - c0.rgb)* c2.a  + (c1.rgb - c0.rgb) * (c1.a - c1.a * c2.a);
	#ifdef LOW_GPU
		lowp vec4 final = vec4(lerpy012 + (c3.rgb - lerpy012) * c3.a, 1.0);
	#else
		lowp vec4 final = vec4( ((lerpy012 + (c3.rgb - lerpy012) * c3.a) * vColor0.rgb) * factor, 1.0);
	#endif
	#ifdef USE_COLORCORECTION
		gl_FragColor = ColorMatrix * final;
	#else
		gl_FragColor = final;
	#endif
}