
#ifdef LOW_GPU
	#ifdef USE_GROUND_CLOUDS
		#undef USE_GROUND_CLOUDS
	#endif
#endif
attribute highp vec4 Position;
attribute highp vec2 TexCoord0;
attribute highp vec2 TexCoord1;
attribute lowp vec4 Color0;
varying mediump vec2 vTexCoord0;
varying mediump vec2 vTexCoord1;
varying mediump vec2 vTexCoord2;
varying mediump vec2 vTexCoord3;
varying lowp 	vec4 vColor0;
uniform highp mat4 WorldViewProjectionMatrix;

mediump vec2 unpackTexCoord(highp float f)
{
	highp float fFrac = fract(f);
	return vec2( (f-fFrac)/1000.0, fFrac);
}
lowp vec3 lerpColor(lowp vec3 a,lowp vec3 b,lowp float f)
{
	return a + (b - a) * f;
}


#ifdef USE_GROUND_CLOUDS
#ifndef CLOUDS_VERTEX_SH
#define CLOUDS_VERTEX_SH
uniform highp vec3 		WorldBox;
uniform highp float		kTimeMinutes;
#ifdef NO_CLOUD_UV
	mediump vec2 ComputeCloudUV(highp vec2 pos_xy)
	{
		mediump vec2 tex_coord = (pos_xy / WorldBox.xy) * 2.0 + 0.5;
		return tex_coord + vec2(0.0,1.0) * kTimeMinutes;
	}
	mediump vec2 GetCloudsUV(highp mat4 world_transform,highp vec4 vpos)
	{
		return ComputeCloudUV((world_transform * vpos).xy);
	}
#else
	varying mediump vec2 cloud_uv_tex_coord;
	void ComputeCloudUV(highp vec2 pos_xy)
	{
		mediump vec2 tex_coord = (pos_xy / WorldBox.xy) * 2.0 + 0.5;
		cloud_uv_tex_coord = tex_coord + vec2(0.0,1.0) * kTimeMinutes;
	}
	void GetCloudsUV(highp mat4 world_transform,highp vec4 vpos)
	{
		ComputeCloudUV((world_transform * vpos).xy);
	}
#endif 
#endif 
#endif 

#ifdef USE_UNIT_SHADOW
	#ifndef USE_GROUND_CLOUDS
		uniform highp vec3 		WorldBox;
	#endif
	uniform highp vec4			kZVisibleSquare;
	varying mediump vec2 ground_uv_texture;
#endif
void main(void)
{
	gl_Position = WorldViewProjectionMatrix * Position;
	
	vTexCoord0 = unpackTexCoord(TexCoord0.x);
	vTexCoord1 = unpackTexCoord(TexCoord0.y);
	vTexCoord2 = unpackTexCoord(TexCoord1.x);
	vTexCoord3 = unpackTexCoord(TexCoord1.y);
	
	vColor0 = Color0;
#ifdef USE_GROUND_CLOUDS
	ComputeCloudUV(Position.xy);
#endif
#ifdef USE_UNIT_SHADOW
	ground_uv_texture = (Position.xy - kZVisibleSquare.xy) / (kZVisibleSquare.zw );
#endif
}