
#ifndef PROFILE_HIGH
	#ifdef USE_GROUND_CLOUDS
		#undef USE_GROUND_CLOUDS
	#endif
#endif
#if defined(LOW_GPU) && defined(POWERVR_GPU)
	#ifdef USE_SELECTION
		#undef USE_SELECTION
	#endif
#endif
#ifdef USE_COLORCORECTION	
	uniform lowp mat4 ColorMatrix;	
#endif
uniform	lowp	sampler2D	DiffuseMap;
#ifdef SPLIT_ALPHA
uniform lowp    sampler2D DiffuseMap_alpha;
uniform lowp    int       DiffuseMap_alphachannel;
#endif
varying		lowp	vec4	vColor;
varying		mediump	vec2	vCoord0;
#ifdef WITH_AMBIENT
uniform		lowp	vec4	AmbientColor;
#endif

#ifndef CLOUDS_VERTEX_FS
#define CLOUDS_VERTEX_FS
#ifdef USE_GROUND_CLOUDS
uniform lowp sampler2D CloudTexture;
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return texture2D(CloudTexture,tex_uv).xyz * 2.00787;
}
#ifndef NO_CLOUD_UV
	varying mediump vec2 cloud_uv_tex_coord;
	mediump vec2 GetCloudUV()
	{
		return cloud_uv_tex_coord;
	}
	lowp vec3 GetCloudColor()
	{
		return GetCloudColor(GetCloudUV());
	}
#endif
#else 
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return vec3(1.0);
}
lowp vec3 GetCloudColor()
{
	return vec3(1.0);
}
#endif 
#endif 

#ifdef USE_SELECTION
uniform highp float kSelectionSin;
uniform	lowp  vec4	SelectColor;
#endif
void main()
{
	#ifdef SPLIT_ALPHA
		
		lowp vec4 alphaCol = texture2D(DiffuseMap_alpha, vCoord0,-1.0);			
		lowp float alpha = alphaCol.r;
		
		#ifdef SA_USE_CHANEL_ALPHA	
		if(DiffuseMap_alphachannel > 2)
			alpha = alphaCol.a;
		#endif
					
		lowp vec4 DiffuseMapColor = vec4(texture2D(DiffuseMap, vCoord0,-1.0).rgb, alpha);
		
	#else
		lowp vec4 DiffuseMapColor = texture2D(DiffuseMap, vCoord0,-1.0);
	#endif
	
	lowp	vec4 	Color = DiffuseMapColor * vColor;
	
#ifdef WITH_AMBIENT
	Color = Color * AmbientColor;
#endif
	
#ifdef USE_GROUND_CLOUDS
	Color.xyz *= GetCloudColor();
#endif
	Color.a = 1.0;
	gl_FragColor					= Color;
#ifdef USE_SELECTION
	
	gl_FragColor = gl_FragColor + kSelectionSin* vec4(0.353,0.245,0.157,0.0);
#endif
#ifdef USE_COLORCORECTION
	gl_FragColor = ColorMatrix * gl_FragColor;
#endif 
}