
#ifndef PROFILE_HIGH
	#ifdef USE_GROUND_CLOUDS
		#undef USE_GROUND_CLOUDS
	#endif
#endif
#ifdef USE_COLORCORECTION	
	uniform lowp mat4 ColorMatrix;	
#endif
uniform	lowp	sampler2D	MapDiffuseSampler;
#ifdef SPLIT_ALPHA
uniform lowp    sampler2D MapDiffuseSampler_alpha;
uniform lowp    int       MapDiffuseSampler_alphachannel;
#endif
#ifdef SNOW
	uniform lowp 	sampler2D	BuildingSnowSampler;
	#ifdef SPLIT_ALPHA
	uniform lowp    sampler2D BuildingSnowSampler_alpha;
	uniform lowp    int       BuildingSnowSampler_alphachannel;
	#endif
#endif
uniform mediump float 		Contrast;
/*#if defined(GHOST)
	uniform		lowp	vec4	DiffuseColor;
#endif*/
varying		lowp	vec3	vColor;
varying		mediump	vec2	vCoord0;
varying		mediump	vec2	vCoord1;
#ifdef SNOW
	varying		mediump	vec2	vCoord2;
#endif

#ifndef CLOUDS_VERTEX_FS
#define CLOUDS_VERTEX_FS
#ifdef USE_GROUND_CLOUDS
uniform lowp sampler2D CloudTexture;
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return texture2D(CloudTexture,tex_uv).xyz * 2.00787;
}
#ifndef NO_CLOUD_UV
	varying mediump vec2 cloud_uv_tex_coord;
	mediump vec2 GetCloudUV()
	{
		return cloud_uv_tex_coord;
	}
	lowp vec3 GetCloudColor()
	{
		return GetCloudColor(GetCloudUV());
	}
#endif
#else 
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return vec3(1.0);
}
lowp vec3 GetCloudColor()
{
	return vec3(1.0);
}
#endif 
#endif 

#ifdef SNOW_INTENSITY
uniform lowp float SnowIntensity;
#endif
void main()
{
	const  lowp vec4 blue = vec4(0.26, 0.31, 0.45, 0.0);
#ifdef SNOW
	#ifdef SPLIT_ALPHA
		lowp vec4 snow_color = vec4(texture2D(BuildingSnowSampler,vCoord2,-1.0).rgb,
									texture2D(BuildingSnowSampler_alpha,vCoord2,-1.0).r);
	#else
		lowp vec4 snow_color = texture2D(BuildingSnowSampler,vCoord2,-1.0);
	#endif
	#ifdef SNOW_INTENSITY
		snow_color.rgb *= SnowIntensity;
	#endif
#endif
#ifdef SPLIT_ALPHA
		
		#ifdef ALPHA_FACTOR		
			lowp vec4 alphaCol = texture2D(MapDiffuseSampler_alpha, vCoord0, -1.0);			
			lowp float DiffuseAlphaTest = alphaCol.r;
			
			#ifdef SA_USE_CHANEL_ALPHA
			if(MapDiffuseSampler_alphachannel > 2)
				DiffuseAlphaTest = alphaCol.a;
			#endif		
		#endif
		lowp vec3 DiffuseMapColor = texture2D(MapDiffuseSampler, vCoord0, -1.0).rgb;
		
		lowp vec4 alphaCol2 = texture2D(MapDiffuseSampler_alpha, vCoord1, -1.0);			
		lowp float DiffuseAlpha = alphaCol2.r;
		
		#ifdef SA_USE_CHANEL_ALPHA
		if(MapDiffuseSampler_alphachannel > 2)
			DiffuseAlpha = alphaCol2.a;
		#endif
		
	#else
		#ifdef ALPHA_FACTOR
			lowp vec4 DiffuseMapColor = texture2D(MapDiffuseSampler, vCoord0, -1.0);
			
			
		lowp float DiffuseAlphaTest = DiffuseMapColor.a;
	#else
		lowp vec3 DiffuseMapColor = texture2D(MapDiffuseSampler, vCoord0, -1.0).rgb;
	#endif
	lowp float DiffuseAlpha = texture2D(MapDiffuseSampler, vCoord1, -1.0).a;
#endif	
	
		
#ifdef SNOW
	DiffuseMapColor.rgb = mix(DiffuseMapColor.rgb,snow_color.rgb,snow_color.a);
#endif
	mediump float  BrightnessContrast = ((DiffuseAlpha * 2.0) - 0.5) * Contrast + 0.5;
	mediump float  MathNegate = 1.0 - BrightnessContrast;
	mediump vec3 done = (((BrightnessContrast + (MathNegate * blue.xyz )) * DiffuseMapColor.rgb) * vColor);
	
#ifdef USE_GROUND_CLOUDS
	done *= GetCloudColor();
#endif
#ifdef ALPHA_FACTOR
	#ifdef SNOW
		
	if(max(DiffuseAlphaTest,snow_color.a) < 0.5)
		discard;
	#else
		if(DiffuseAlphaTest < 0.5)
			discard;
	#endif
#endif
	gl_FragColor.rgb				= done;
	gl_FragColor.a					= 1.0;
	
#ifdef USE_COLORCORECTION
	gl_FragColor = ColorMatrix * gl_FragColor;
#endif 
}