
uniform	lowp	sampler2D	MapDiffuseSampler;
uniform	lowp	sampler2D	MapLightMapSampler;
#ifdef SNOW
	uniform lowp 	sampler2D	BuildingSnowSampler;
	#ifdef SPLIT_ALPHA
	uniform lowp    sampler2D 	BuildingSnowSampler_alpha;
	uniform lowp    int       	BuildingSnowSampler_alphachannel;
	#endif
#endif
#if defined(GHOST) || defined ( GHOST_WALS )
	uniform		lowp	vec4	DiffuseColor;
#endif

#ifdef BUILDING_HIGHLIGHT
uniform 	highp float 	hTimeSeconds;
uniform		highp float		kSinSeconds;
varying		highp float		zHeight;
lowp vec3 GetHighliedValue(lowp vec3 i)
{
	
	
	
	lowp float value = kSinSeconds * 0.75;
	
	
	lowp vec3 tc = i + vec3(value,0.0,0.0);
	return mix(i,tc * i,kSinSeconds);
}
#else
lowp vec3 GetHighliedValue(lowp vec3 i)
{
	return i;
}
#endif
lowp vec3 ComposeGhostColor(lowp vec3 original,lowp vec4 gc)
{
	return original;
}
lowp vec3 ComposeGhostModulatedColor(lowp vec3 original,lowp vec4 gc)
{
	
	
	lowp vec3 gold_ish = vec3(0.9 , 0.3 /*0.8235*/,0.01);
	lowp vec3 c = original * gc.rgb ;
	if(gc.a < 0.1)
		c = c + gold_ish;
	return mix(c,vec3(1.0,0.207,0.207),gc.a);
}
lowp vec3 ComposeWallColor(lowp vec3 original,lowp vec4 gc)
{
	return ComposeGhostModulatedColor(original,gc);
}

varying		lowp	vec3	vColor;
varying		mediump	vec2	vCoord0;
varying		mediump	vec2	vCoord1;
#ifdef SNOW
	varying		mediump	vec2	vCoord2;
#endif

#ifndef CLOUDS_VERTEX_FS
#define CLOUDS_VERTEX_FS
#ifdef USE_GROUND_CLOUDS
uniform lowp sampler2D CloudTexture;
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return texture2D(CloudTexture,tex_uv).xyz * 2.00787;
}
#ifndef NO_CLOUD_UV
	varying mediump vec2 cloud_uv_tex_coord;
	mediump vec2 GetCloudUV()
	{
		return cloud_uv_tex_coord;
	}
	lowp vec3 GetCloudColor()
	{
		return GetCloudColor(GetCloudUV());
	}
#endif
#else 
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return vec3(1.0);
}
lowp vec3 GetCloudColor()
{
	return vec3(1.0);
}
#endif 
#endif 

#ifdef USE_SELECTION
uniform highp float 	kSelectionSin;
uniform	lowp  vec4		SelectColor;
uniform lowp  vec4 		SelectionColor;
#endif
#ifdef SNOW_INTENSITY
uniform lowp float SnowIntensity;
#endif
void main()
{
#ifdef USE_OUTLINE
	gl_FragColor = vec4(1.0,1.0,0.0,0.0);
#else
	lowp vec3 DiffuseMapColor = texture2D(MapDiffuseSampler, vCoord0, -1.0).rgb;
	
#ifdef LIGHT_USE_CHANEL_R
	lowp float MapLightMapColor = texture2D(MapLightMapSampler, vCoord1, -1.0).r;
#endif
#ifdef LIGHT_USE_CHANEL_G
	lowp float MapLightMapColor = texture2D(MapLightMapSampler, vCoord1, -1.0).g;
#endif
#ifdef LIGHT_USE_CHANEL_B
	lowp float MapLightMapColor = texture2D(MapLightMapSampler, vCoord1, -1.0).b;
#endif
	
#ifdef SNOW
	#ifdef SPLIT_ALPHA
		lowp vec4 snow_color = vec4(texture2D(BuildingSnowSampler,vCoord2,-1.0).rgb,texture2D(BuildingSnowSampler_alpha,vCoord2,-1.0)[BuildingSnowSampler_alphachannel]);
	#else
		lowp vec4 snow_color = texture2D(BuildingSnowSampler,vCoord2,-1.0);
	#endif
	#ifdef SNOW_INTENSITY
		snow_color.rgb *= SnowIntensity;
	#endif
	DiffuseMapColor = mix(DiffuseMapColor,snow_color.rgb,snow_color.a);
#endif
	mediump vec3 done = DiffuseMapColor * (MapLightMapColor * 2.0) * vColor;
#ifdef USE_GROUND_CLOUDS
	done *= GetCloudColor();
#endif
	#ifdef GHOST_WALS
		gl_FragColor.rgb				= ComposeWallColor(done,DiffuseColor);
		gl_FragColor.a					= DiffuseColor.a;
	#elif defined(GHOST)
		gl_FragColor.rgb				= ComposeGhostColor(done,DiffuseColor);
		gl_FragColor.a					= DiffuseColor.a;
	#else
		lowp	float	factor 			= 1.0;
		gl_FragColor.rgb				= done * factor;
		gl_FragColor.a					= 1.0;
	#endif
	
	#ifdef USE_SELECTION
		
		gl_FragColor = mix(gl_FragColor,gl_FragColor + (SelectionColor*SelectionColor.w),kSelectionSin);
	#endif
#endif 
}