
#ifdef GL_FRAGMENT_PRECISION_HIGH
	
	#ifdef GLITCH_USE_HIGHP
		#define MAXP highp
	#else
		#define MAXP mediump
	#endif
#else
	
	#define MAXP mediump
	
	#ifdef GLITCH_FORCE_USE_BIAS
		#ifndef GLITCH_USE_BIAS
			#define GLITCH_USE_BIAS
		#endif
	#else
		#ifdef GLITCH_USE_BIAS
			#undef GLITCH_USE_BIAS
		#endif
	#endif
#endif
#if defined(GLITCH_USE_BIAS) && !defined(GLITCH_DEBUG_SUBSTITUTE)
	#define TEXTURE2D(sampler, coord, bias) texture2D(sampler, coord, bias)
#else
	#define TEXTURE2D(sampler, coord, bias) texture2D(sampler, coord)
#endif
#ifdef TEXTURED
uniform lowp sampler2D Sampler0;
#    ifdef SPLIT_ALPHA
uniform lowp sampler2D Sampler0_alpha;
#    endif
varying MAXP vec2 vTexCoord0;
#    if defined(GLITCH_USE_BIAS) && !defined(GLITCH_DEBUG_SUBSTITUTE)
uniform mediump float Sampler0_bias;
#    endif
#endif
#if defined(MULTITEXTURED) && !defined(GLITCH_DEBUG_SUBSTITUTE)
uniform lowp sampler2D Sampler1;
varying MAXP vec2 vTexCoord1;
uniform lowp float envmapIntensity;
#    ifdef GLITCH_USE_BIAS
uniform mediump float Sampler1_bias;
#    endif
#endif 
#if defined(LIGHTMAP) && !defined(GLITCH_DEBUG_SUBSTITUTE)
varying MAXP vec2 vTexCoord2;
uniform lowp sampler2D Sampler2;
#    ifdef GLITCH_USE_BIAS
uniform mediump float Sampler2_bias;
#    endif
#endif
#if defined(FOG) && !defined(GLITCH_DEBUG_SUBSTITUTE)
uniform lowp vec4 fogcolor;
varying lowp float fogFactor;
#endif 
#if defined(GLITCH_DEBUG_SUBSTITUTE)
uniform lowp vec4 DiffuseColor;
#else
varying lowp vec4 vColor0;
#endif
#if defined(ALPHATEST) && !defined(GLITCH_DEBUG_SUBSTITUTE)
uniform lowp float AlphaRef;
#endif
void main()
{
#if defined(GLITCH_DEBUG_SUBSTITUTE)
	lowp vec4 color = DiffuseColor;
#else
	lowp vec4 color = vColor0;
#endif
#ifdef TEXTURED
	#ifdef SPLIT_ALPHA
	color *= vec4(TEXTURE2D(Sampler0, vTexCoord0, Sampler0_bias).rgb,
				  TEXTURE2D(Sampler0_alpha, vTexCoord0, Sampler0_bias).g);
	#else
	color *= TEXTURE2D(Sampler0, vTexCoord0, Sampler0_bias);
	#endif
#endif
#if defined(LIGHTMAP) && !defined(GLITCH_DEBUG_SUBSTITUTE)
	color *= TEXTURE2D(Sampler2, vTexCoord2, Sampler2_bias);
#endif
#if defined(ALPHATEST) && !defined(GLITCH_DEBUG_SUBSTITUTE)
	highp float discard_alpha = color.a;
	
	
	
	
	
#endif
#if defined(MULTITEXTURED) && !defined(GLITCH_DEBUG_SUBSTITUTE)
	color.rgb += TEXTURE2D(Sampler1, vTexCoord1, Sampler1_bias).rgb * envmapIntensity;
#endif 
#if defined(FOG) && !defined(GLITCH_DEBUG_SUBSTITUTE)
#    ifdef ADDITIVEBLEND
    
    
    color.rgb = mix(color.rgb, vec3(0.0, 0.0, 0.0), fogFactor * length(color.rgb) * color.a);
#    else
    color.rgb = mix(color.rgb, fogcolor.rgb, fogFactor);
#    endif
#endif 
#if defined(ALPHATEST) && !defined(GLITCH_DEBUG_SUBSTITUTE)
	if (discard_alpha <= AlphaRef)
	{
		discard;
	}
#endif
	gl_FragColor = color;
}