
#ifndef PROFILE_HIGH
	#ifdef USE_GROUND_CLOUDS
		#undef USE_GROUND_CLOUDS
	#endif
#endif
#ifdef USE_COLORCORECTION	
	uniform lowp mat4 ColorMatrix;	 
#endif
uniform lowp sampler2D             MapDiffuseSampler;
#ifdef SPLIT_ALPHA
uniform lowp    sampler2D MapDiffuseSampler_alpha;
uniform lowp    int       MapDiffuseSampler_alphachannel;
#endif
varying	  mediump    	vec2     vCoord0;
varying   lowp    		vec4     vColor0;
#ifdef USE_ALPHA_FADE
uniform lowp float AlphaMultiplier;
#endif
 
#ifdef ENABLE_CLOUDS

#ifndef CLOUDS_VERTEX_FS
#define CLOUDS_VERTEX_FS
#ifdef USE_GROUND_CLOUDS
uniform lowp sampler2D CloudTexture;
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return texture2D(CloudTexture,tex_uv).xyz * 2.00787;
}
#ifndef NO_CLOUD_UV
	varying mediump vec2 cloud_uv_tex_coord;
	mediump vec2 GetCloudUV()
	{
		return cloud_uv_tex_coord;
	}
	lowp vec3 GetCloudColor()
	{
		return GetCloudColor(GetCloudUV());
	}
#endif
#else 
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return vec3(1.0);
}
lowp vec3 GetCloudColor()
{
	return vec3(1.0);
}
#endif 
#endif 

#endif
#ifdef GHOST

#ifdef BUILDING_HIGHLIGHT
uniform 	highp float 	hTimeSeconds;
uniform		highp float		kSinSeconds;
varying		highp float		zHeight;
lowp vec3 GetHighliedValue(lowp vec3 i)
{
	
	
	
	lowp float value = kSinSeconds * 0.75;
	
	
	lowp vec3 tc = i + vec3(value,0.0,0.0);
	return mix(i,tc * i,kSinSeconds);
}
#else
lowp vec3 GetHighliedValue(lowp vec3 i)
{
	return i;
}
#endif
lowp vec3 ComposeGhostColor(lowp vec3 original,lowp vec4 gc)
{
	return original;
}
lowp vec3 ComposeGhostModulatedColor(lowp vec3 original,lowp vec4 gc)
{
	
	
	lowp vec3 gold_ish = vec3(0.9 , 0.3 /*0.8235*/,0.01);
	lowp vec3 c = original * gc.rgb ;
	if(gc.a < 0.1)
		c = c + gold_ish;
	return mix(c,vec3(1.0,0.207,0.207),gc.a);
}
lowp vec3 ComposeWallColor(lowp vec3 original,lowp vec4 gc)
{
	return ComposeGhostModulatedColor(original,gc);
}

uniform		lowp	vec4	DiffuseColor;
#endif
#ifdef ALPHA_DIFFUSE
	uniform lowp 	vec4	DiffuseColor;
#endif
void main()
{
    lowp vec4 _MapDiffuse1;
	
	#ifdef SPLIT_ALPHA
		
		lowp vec4 alphaCol = texture2D(MapDiffuseSampler_alpha, vCoord0,-1.0);			
		lowp float alpha = alphaCol.r;
		
		#ifdef SA_USE_CHANEL_ALPHA	
		if(MapDiffuseSampler_alphachannel > 2)
			alpha = alphaCol.a;
		#endif
			
		_MapDiffuse1 = vec4(texture2D(MapDiffuseSampler, vCoord0,-1.0).rgb, alpha);
		
	#else
		_MapDiffuse1 = texture2D(MapDiffuseSampler, vCoord0,-1.0);
	#endif
	#if defined(GHOST)
		gl_FragColor.rgb				= ComposeGhostModulatedColor(_MapDiffuse1.rgb,DiffuseColor);
		gl_FragColor.a					= _MapDiffuse1.a;
	#else
#ifdef USE_ALPHA_FADE
	_MapDiffuse1.a = _MapDiffuse1.a * AlphaMultiplier;
#endif
#if defined(ENABLE_CLOUDS) && defined(USE_GROUND_CLOUDS)
	gl_FragColor = _MapDiffuse1 * vColor0 * vec4(GetCloudColor(),1.0);
#else
	gl_FragColor = (_MapDiffuse1 * vColor0);
#endif
#ifdef ALPHA_DIFFUSE
	gl_FragColor *= DiffuseColor;
#endif
	#endif
#ifdef USE_COLORCORECTION
	gl_FragColor = ColorMatrix * gl_FragColor;
#endif
} 