
#ifndef PROFILE_HIGH
	#ifdef USE_GROUND_CLOUDS
		#undef USE_GROUND_CLOUDS
	#endif
#endif
#ifdef USE_COLORCORECTION	
	uniform lowp mat4 ColorMatrix;	
#endif
uniform	lowp	sampler2D	DiffuseMap;
#ifdef SPLIT_ALPHA
uniform lowp    sampler2D DiffuseMap_alpha;
uniform lowp    int       DiffuseMap_alphachannel;
#endif
varying		lowp	vec4	vColor;
varying		mediump	vec2	vCoord0;
#ifdef GHOST
	uniform		lowp	vec4	DiffuseColor;
#endif

#ifdef BUILDING_HIGHLIGHT
uniform 	highp float 	hTimeSeconds;
uniform		highp float		kSinSeconds;
varying		highp float		zHeight;
lowp vec3 GetHighliedValue(lowp vec3 i)
{
	
	
	
	lowp float value = kSinSeconds * 0.75;
	
	
	lowp vec3 tc = i + vec3(value,0.0,0.0);
	return mix(i,tc * i,kSinSeconds);
}
#else
lowp vec3 GetHighliedValue(lowp vec3 i)
{
	return i;
}
#endif
lowp vec3 ComposeGhostColor(lowp vec3 original,lowp vec4 gc)
{
	return original;
}
lowp vec3 ComposeGhostModulatedColor(lowp vec3 original,lowp vec4 gc)
{
	
	
	lowp vec3 gold_ish = vec3(0.9 , 0.3 /*0.8235*/,0.01);
	lowp vec3 c = original * gc.rgb ;
	if(gc.a < 0.1)
		c = c + gold_ish;
	return mix(c,vec3(1.0,0.207,0.207),gc.a);
}
lowp vec3 ComposeWallColor(lowp vec3 original,lowp vec4 gc)
{
	return ComposeGhostModulatedColor(original,gc);
}


#ifndef CLOUDS_VERTEX_FS
#define CLOUDS_VERTEX_FS
#ifdef USE_GROUND_CLOUDS
uniform lowp sampler2D CloudTexture;
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return texture2D(CloudTexture,tex_uv).xyz * 2.00787;
}
#ifndef NO_CLOUD_UV
	varying mediump vec2 cloud_uv_tex_coord;
	mediump vec2 GetCloudUV()
	{
		return cloud_uv_tex_coord;
	}
	lowp vec3 GetCloudColor()
	{
		return GetCloudColor(GetCloudUV());
	}
#endif
#else 
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return vec3(1.0);
}
lowp vec3 GetCloudColor()
{
	return vec3(1.0);
}
#endif 
#endif 

void main()
{
	
	#ifdef SPLIT_ALPHA
		
		lowp vec4 alphaCol = texture2D(DiffuseMap_alpha, vCoord0,-1.0);			
		lowp float alpha = alphaCol.r;
		
		#ifdef SA_USE_CHANEL_ALPHA	
		if(DiffuseMap_alphachannel > 2)
			alpha = alphaCol.a;
		#endif
		
		lowp vec4 DiffuseMapColor = vec4(texture2D(DiffuseMap, vCoord0,-1.0).rgb, alpha);
		
	#else
		lowp vec4 DiffuseMapColor = texture2D(DiffuseMap, vCoord0,-1.0);
	#endif	
	
	lowp	vec4 	Color			= DiffuseMapColor * vColor;
#ifdef USE_GROUND_CLOUDS
	lowp vec3 factor = GetCloudColor();
#else
	lowp float factor = 1.0;
#endif
	#ifdef GHOST
		gl_FragColor.rgb				= ComposeGhostModulatedColor(Color.rgb,DiffuseColor) * factor;
		gl_FragColor.a					= Color.a;
	#else
		gl_FragColor.rgb				= Color.rgb * factor;
		gl_FragColor.a					= 1.0;
	#endif
	
	
#ifdef USE_COLORCORECTION
	gl_FragColor = ColorMatrix * gl_FragColor;
#endif
}