
#ifndef PROFILE_HIGH
	#ifdef USE_GROUND_CLOUDS
		#undef USE_GROUND_CLOUDS
	#endif
#endif
uniform	lowp	sampler2D	WaterTextureSampler;
#ifdef SPLIT_ALPHA
uniform lowp    sampler2D WaterTextureSampler_alpha;
uniform lowp    int       WaterTextureSampler_alphachannel;
#endif
varying		mediump	vec2	vCoord0;
varying		lowp	vec4	vColor0;
#ifndef LOW_GPU 
varying 	highp 	vec3	halfNormal;
varying		lowp 	vec3	specular_color;
uniform highp float WaterDistorsion;
uniform highp float WaterOffsetU;
uniform highp float WaterOffsetV;
uniform highp float WaterGloss;
uniform highp vec3 camera_pos;
uniform highp vec3 light_pos;
#endif

#ifndef CLOUDS_VERTEX_FS
#define CLOUDS_VERTEX_FS
#ifdef USE_GROUND_CLOUDS
uniform lowp sampler2D CloudTexture;
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return texture2D(CloudTexture,tex_uv).xyz * 2.00787;
}
#ifndef NO_CLOUD_UV
	varying mediump vec2 cloud_uv_tex_coord;
	mediump vec2 GetCloudUV()
	{
		return cloud_uv_tex_coord;
	}
	lowp vec3 GetCloudColor()
	{
		return GetCloudColor(GetCloudUV());
	}
#endif
#else 
lowp vec3 GetCloudColor(mediump vec2 tex_uv)
{
	return vec3(1.0);
}
lowp vec3 GetCloudColor()
{
	return vec3(1.0);
}
#endif 
#endif 

void main()
{
#ifdef SPLIT_ALPHA
	
		lowp vec4 alphaCol = texture2D(WaterTextureSampler_alpha, vCoord0,-1.0);			
		lowp float alpha = alphaCol.r;
		
		#ifdef SA_USE_CHANEL_ALPHA	
		if(WaterTextureSampler_alphachannel > 2)
			alpha = alphaCol.a;
		#endif
		
		lowp vec4 DiffuseMapColor = vec4(texture2D(WaterTextureSampler, vCoord0,-1.0).rgb,
#ifdef LOW_GPU 
			1.0);
#else
			alpha);
#endif
	
#else
		lowp vec4 DiffuseMapColor = texture2D(WaterTextureSampler, vCoord0,-1.0);
#endif	
#ifndef LOW_GPU 
	highp float distort = DiffuseMapColor.a * WaterDistorsion;
	mediump vec2 water_offset_coord = vCoord0 + vec2(WaterOffsetU,WaterOffsetV);
	water_offset_coord += distort;
#ifdef SPLIT_ALPHA
	
	lowp vec4 alphaCol2 = texture2D(WaterTextureSampler_alpha, water_offset_coord,-1.0);			
	lowp float alpha2 = alphaCol2.r;
	
	#ifdef SA_USE_CHANEL_ALPHA		
	if(WaterTextureSampler_alphachannel > 2)
		alpha2 = alphaCol2.a;
	#endif
		
	lowp vec4 wataaaaaa = vec4(texture2D(WaterTextureSampler, water_offset_coord,-1.0).rgb, alpha2);
	
#else
	lowp vec4 wataaaaaa = texture2D(WaterTextureSampler, water_offset_coord,-1.0);
#endif	
	mediump vec3 final_ambient = wataaaaaa.rgb * vColor0.rgb;
	mediump float final_gloss = WaterGloss;
	mediump float final_opacity = vColor0.a;
	highp float ndh = normalize(halfNormal).z;
	final_ambient += specular_color * pow(ndh,final_gloss) * wataaaaaa.a;
#ifdef USE_GROUND_CLOUDS
	final_ambient *= GetCloudColor();
#endif
	gl_FragColor = vec4(final_ambient,final_opacity);
#else
	gl_FragColor = DiffuseMapColor * vColor0;
#endif
}