
#ifndef PROFILE_HIGH
	#ifdef USE_GROUND_CLOUDS
		#undef USE_GROUND_CLOUDS
	#endif
#endif

#ifndef _VERTEX_BASICS
#define _VERTEX_BASICS
attribute 	highp	vec4 	Position;

#ifndef _MATRIXV
#define _MATRIXV
uniform 	highp	mat4	WorldViewProjection;
uniform 	highp	mat4	WorldViewTransposed;
uniform		highp	mat4	matworld;
#endif

void		setWVP()
{
	gl_Position	= WorldViewProjection * Position;
}
highp vec4	getWorldPos()
{
	return (matworld * Position);
}
#endif

attribute	mediump	vec2	Coord0;
attribute	lowp	vec4	Color0;
varying		mediump	vec2	vCoord0;
varying		lowp	vec4	vColor0;
#ifndef LOW_GPU 
varying 	highp 	vec3	halfNormal;
varying		lowp 	vec3	specular_color;
#endif
uniform lowp vec3 light_color;
uniform highp float WaterSpecular;
uniform highp vec3 camera_pos;
uniform highp vec3 light_pos;
#ifdef LOW_GPU 
uniform highp float WaterOffsetU;
uniform highp float WaterOffsetV;
#endif

#ifdef USE_GROUND_CLOUDS
#ifndef CLOUDS_VERTEX_SH
#define CLOUDS_VERTEX_SH
uniform highp vec3 		WorldBox;
uniform highp float		kTimeMinutes;
#ifdef NO_CLOUD_UV
	mediump vec2 ComputeCloudUV(highp vec2 pos_xy)
	{
		mediump vec2 tex_coord = (pos_xy / WorldBox.xy) * 2.0 + 0.5;
		return tex_coord + vec2(0.0,1.0) * kTimeMinutes;
	}
	mediump vec2 GetCloudsUV(highp mat4 world_transform,highp vec4 vpos)
	{
		return ComputeCloudUV((world_transform * vpos).xy);
	}
#else
	varying mediump vec2 cloud_uv_tex_coord;
	void ComputeCloudUV(highp vec2 pos_xy)
	{
		mediump vec2 tex_coord = (pos_xy / WorldBox.xy) * 2.0 + 0.5;
		cloud_uv_tex_coord = tex_coord + vec2(0.0,1.0) * kTimeMinutes;
	}
	void GetCloudsUV(highp mat4 world_transform,highp vec4 vpos)
	{
		ComputeCloudUV((world_transform * vpos).xy);
	}
#endif 
#endif 
#endif 

void main()
{
#ifdef LOW_GPU 
	vCoord0		= Coord0 + vec2(WaterOffsetU,WaterOffsetV);
#else
	vCoord0		= Coord0;
#endif
	vColor0		= Color0;
	setWVP();
#ifndef LOW_GPU 
	highp vec3 vWorldPosition = getWorldPos().xyz;
	highp vec3 E = normalize(camera_pos - vWorldPosition);
	highp vec3 L = normalize(light_pos - vWorldPosition);
	halfNormal = E + L;
	specular_color = light_color * WaterSpecular;
#endif
#ifdef USE_GROUND_CLOUDS
	ComputeCloudUV( vWorldPosition.xy );
#endif
}